@@ -1,19 +1,20 @@
 package AnyEvent::Impl::Event;
 
 no warnings;
+use strict;
 
 use Event ();
 
 sub io {
    my ($class, %arg) = @_;
    $arg{fd} = delete $arg{fh};
-   bless \(my $x = Event->io (%arg)), $class
+   bless \(Event->io (%arg)), $class
 }
 
 sub timer {
    my ($class, %arg) = @_;
    my $cb = delete $arg{cb};
-   bless \(my $w = Event->timer (
+   bless \(Event->timer (
       %arg,
       cb => sub {
          $_[0]->w->cancel;
@@ -22,24 +23,15 @@ sub timer {
    )), $class
 }
 
+sub signal {
+   my ($class, %arg) = @_;
+   bless \(Event->signal (%arg)), $class
+}
+
 sub DESTROY {
    ${$_[0]}->cancel;
 }
 
-sub condvar {
-   my $class = shift;
-
-   bless \my $flag, $class
-}
-
-sub broadcast {
-   ${$_[0]}++;
-}
-
-sub wait {
-   Event::one_event while !${$_[0]};
-}
-
 sub one_event {
    Event::one_event;
 }
